@@ -6,20 +6,23 @@ use crate::builder::error::Error;
 use crate::components::clock::Clock;
 use crate::components::io::{AtHeight, Io};
 use crate::components::scheduler::Scheduler;
-use crate::components::verifier::Verifier;
-use crate::light_client::{LightClient, Options};
-use crate::operations::Hasher;
-use crate::predicates::VerificationPredicates;
+use crate::light_client::LightClient;
 use crate::state::{State, VerificationTrace};
 use crate::store::LightStore;
 use crate::supervisor::Instance;
-use crate::types::{LightBlock, PeerId, Status};
+use crate::verifier::operations::Hasher;
+use crate::verifier::options::Options;
+use crate::verifier::predicates::VerificationPredicates;
+use crate::verifier::types::{LightBlock, PeerId, Status};
+use crate::verifier::Verifier;
 
 #[cfg(feature = "rpc-client")]
 use {
-    crate::components::clock::SystemClock, crate::components::io::ProdIo,
-    crate::components::scheduler, crate::components::verifier::ProdVerifier,
-    crate::operations::ProdHasher, crate::predicates::ProdPredicates, std::time::Duration,
+    crate::components::clock::SystemClock,
+    crate::components::io::ProdIo,
+    crate::components::scheduler,
+    crate::verifier::{operations::ProdHasher, predicates::ProdPredicates, ProdVerifier},
+    core::time::Duration,
     tendermint_rpc as rpc,
 };
 
